summaryrefslogtreecommitdiff
path: root/drivers/staging/brcm80211/include/wlioctl.h
diff options
context:
space:
mode:
authorGreg Kroah-Hartman <gregkh@suse.de>2010-10-08 11:11:13 -0700
committerGreg Kroah-Hartman <gregkh@suse.de>2010-10-08 11:11:13 -0700
commit3e26416e2f7fc2781c084c4ea51227aef30336de (patch)
treeb29d7e6a00a3b28e790e357a448c8811e9f4f8a1 /drivers/staging/brcm80211/include/wlioctl.h
parent66cbd3ab35d35580ddf98304c280a6231685aa41 (diff)
Staging: brcm80211: s/int32/s32/
Use the kernel types, don't invent your own. Cc: Brett Rudley <brudley@broadcom.com> Cc: Henry Ptasinski <henryp@broadcom.com> Cc: Nohee Ko <noheek@broadcom.com> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/brcm80211/include/wlioctl.h')
-rw-r--r--drivers/staging/brcm80211/include/wlioctl.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/drivers/staging/brcm80211/include/wlioctl.h b/drivers/staging/brcm80211/include/wlioctl.h
index 6ac4f3155bb4..66b72765245c 100644
--- a/drivers/staging/brcm80211/include/wlioctl.h
+++ b/drivers/staging/brcm80211/include/wlioctl.h
@@ -183,7 +183,7 @@ typedef struct wl_extdscan_params {
wlc_ssid_t ssid[WLC_EXTDSCAN_MAX_SSID]; /* ssid list */
u32 tx_rate; /* in 500ksec units */
wl_scan_type_t scan_type; /* enum */
- int32 channel_num;
+ s32 channel_num;
chan_scandata_t channel_list[1]; /* list of chandata structs */
} wl_extdscan_params_t;
@@ -205,23 +205,23 @@ typedef struct wl_scan_params {
* DOT11_BSSTYPE_ANY/INFRASTRUCTURE/INDEPENDENT
*/
u8 scan_type; /* flags, 0 use default */
- int32 nprobes; /* -1 use default, number of probes per channel */
- int32 active_time; /* -1 use default, dwell time per channel for
+ s32 nprobes; /* -1 use default, number of probes per channel */
+ s32 active_time; /* -1 use default, dwell time per channel for
* active scanning
*/
- int32 passive_time; /* -1 use default, dwell time per channel
+ s32 passive_time; /* -1 use default, dwell time per channel
* for passive scanning
*/
- int32 home_time; /* -1 use default, dwell time for the home channel
+ s32 home_time; /* -1 use default, dwell time for the home channel
* between channel scans
*/
- int32 channel_num; /* count of channels and ssids that follow
+ s32 channel_num; /* count of channels and ssids that follow
*
* low half is count of channels in channel_list, 0
* means default (use all available channels)
*
* high half is entries in wlc_ssid_t array that
* follows channel_list, aligned for int32 (4 bytes)
* meaning an odd channel count implies a 2-byte pad
* between end of channel_list and first ssid
*
@@ -333,7 +333,7 @@ typedef struct wl_u32_list {
/* used for association with a specific BSSID and chanspec list */
typedef struct wl_assoc_params {
struct ether_addr bssid; /* 00:00:00:00:00:00: broadcast scan */
- int32 chanspec_num; /* 0: all available channels,
+ s32 chanspec_num; /* 0: all available channels,
* otherwise count of chanspecs in chanspec_list
*/
chanspec_t chanspec_list[1]; /* list of chanspecs */
@@ -435,7 +435,7 @@ typedef struct wl_country {
char country_abbrev[WLC_CNTRY_BUF_SZ]; /* nul-terminated country code used in
* the Country IE
*/
- int32 rev; /* revision specifier for ccode
+ s32 rev; /* revision specifier for ccode
* on set, -1 indicates unspecified.
* on get, rev >= 0
*/
@@ -205,23 +205,23 @@ typedef struct wl_scan_params {
*
* high half is entries in wlc_ssid_t array that
- * follows channel_list, aligned for int32 (4 bytes)
+ * follows channel_list, aligned for s32 (4 bytes)
* meaning an odd channel count implies a 2-byte pad
* between end of channel_list and first ssid